==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var MovingAverageConvergenceDivergenceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MovingAverageConvergenceDivergenceIndicator, _super);
    function MovingAverageConvergenceDivergenceIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 9;
        return _this;
    }
    MovingAverageConvergenceDivergenceIndicator.prototype.get_ts = function () {
        return 1;
    };
    MovingAverageConvergenceDivergenceIndicator.prototype.get_ul = function () {
        return new MovingAverageConvergenceDivergenceIndicatorStrategy();
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.get_uy = function () {
        return MovingAverageConvergenceDivergenceIndicator.$;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.u9));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.u9, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.ut = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.u8));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.u8, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.uq = function () {
        return this.longPeriod;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "signalPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.va));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.va, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.t1 = function () {
        return this.signalPeriod;
    };
    MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    MovingAverageConvergenceDivergenceIndicator.u9 = StrategyBasedIndicator.u5(10, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.u8 = StrategyBasedIndicator.u1(30, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.va = StrategyBasedIndicator.u4(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");
    return MovingAverageConvergenceDivergenceIndicator;
}(StrategyBasedIndicator));
export { MovingAverageConvergenceDivergenceIndicator };

==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var MovingAverageConvergenceDivergenceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MovingAverageConvergenceDivergenceIndicator, _super);
    function MovingAverageConvergenceDivergenceIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 9;
        return _this;
    }
    MovingAverageConvergenceDivergenceIndicator.prototype.bg = function () {
        return new MovingAverageConvergenceDivergenceIndicator();
    };
    MovingAverageConvergenceDivergenceIndicator.prototype.get_x6 = function () {
        return 1;
    };
    MovingAverageConvergenceDivergenceIndicator.prototype.get_yz = function () {
        return new MovingAverageConvergenceDivergenceIndicatorStrategy();
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.get_zc = function () {
        return MovingAverageConvergenceDivergenceIndicator.$;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zn));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zn, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.y7 = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zm));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zm, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.y4 = function () {
        return this.longPeriod;
    };
    Object.defineProperty(MovingAverageConvergenceDivergenceIndicator.prototype, "signalPeriod", {
        get: function () {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zo));
        },
        set: function (a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zo, a);
        },
        enumerable: false,
        configurable: true
    });
    MovingAverageConvergenceDivergenceIndicator.prototype.yf = function () {
        return this.signalPeriod;
    };
    MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    MovingAverageConvergenceDivergenceIndicator.zn = StrategyBasedIndicator.zj(10, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zm = StrategyBasedIndicator.zf(30, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zo = StrategyBasedIndicator.zi(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");
    return MovingAverageConvergenceDivergenceIndicator;
}(StrategyBasedIndicator));
export { MovingAverageConvergenceDivergenceIndicator };
